#
# spec file for package bittwist
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2016-2023, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bittwist
Version:        3.8
Release:        2.5
Summary:        A libpcap-based Ethernet packet generator
License:        GPL-2.0-only
Group:          Productivity/Networking/Diagnostic
#Git-Clone:     https://github.com/ayeowch/bittwist.git
URL:            https://bittwist.sourceforge.io
Source:         http://downloads.sourceforge.net/%{name}/Linux/Bit-Twist%%20%{version}/%{name}-linux-%{version}.tar.gz
Patch0:         bittwist-makefile.diff
BuildRequires:  libpcap-devel

%description
Bit-Twist is a libpcap-based Ethernet packet generator complementing
tcpdump. It replays traffic captured in .pcap files onto a live
network. It comes with a trace file editor to allow you to change the
contents of a trace file.

A packet generator is useful in simulating networking traffic or
testing firewall, IDS, and IPS, and troubleshooting various network
problems.

%prep
%autosetup -p1 -n %{name}-linux-%{version}

%build
export CFLAGS="%{optflags}"
%make_build

%install
%make_install prefix=/usr

%files
%license COPYING
%doc AUTHORS BUGS CHANGES README.md VERSION
%{_bindir}/bittwist
%{_bindir}/bittwiste
%{_mandir}/man1/bittwist.1%{?ext_man}
%{_mandir}/man1/bittwiste.1%{?ext_man}

%changelog
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Fri Sep 22 2023 Ming Li <mli@suse.com>
- Update to version 3.8
  * bumped from gcc -O2 to -O3 optimization flag:
    https://gcc.gnu.org/onlinedocs/gcc/Optimize-Options.html#index-O3
  bittwist (generator)
  * added RFC 2544 benchmark data generator and benchmark page
  * improved actual inter-packet gap replay by using token bucket algorithm for
    short IPG and self-regulated timer for long IPG
* Sun Jul  2 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 3.7
  Changes since 2.0:
  general
  * added support for trace files with nanosecond resolution.
  * updated manual pages.
  * use in-memory trace files when sending packets in loop.
  * fixed integer overflow in stats output.
  * added static code analysis in Makefile (make check).
  * reformatted source files for C17 standard.
  * added initial python testing framework for Linux systems.
  bittwist (generator):
  * 30%% speed up when sending large pcap file.
  * fixed linerate throttling.
  * updated -p option to send packets at set packets per second
    (pps).
  * added -t option to set inter-packet gap (this was previously
  - p option).
  * removed speed (-m) flag; use -p/-r to shape throughput.
  * updated linerate (-r) flag to use token bucket algorithm.
  bittwiste (editor)
  * added -G option to set fixed or random inter-packet gap in
    microseconds.
  * added support for CIDR notation when modifying IPv4/IPv6
    addressA.
  * added support for random MAC address.
  * added option to edit IPv6 next header.
  * added random number support for id, ttl, proto, next header,
    hop limit.
  * added option to set uniformly distributed random number
    (mersenne twister). for tcp/udp source/destination port and
    tcp sequence/acknowledgment number.
  * added -N flag to duplicate packets from trace file, e.g.
  - N 100000 to repeat packets from trace file for 100,000 times
  * added ip6tcp and ip6udp templates.
  * updated -I flag to allow loading trace file from built-in
    templates.
  * options to edit IPv4/IPv6 packets to allow testing of
    classification/queuing.  features of switches/routers, e.g.
    + -T ip -e 3 to indicate congestion to the end hosts
    + -T ip6 -c 16 to classify packet for operation and management
    of the network
    + -T ip6 -f 0xfffff to set custom flow label
  * added support for IPv6 packets.
  * improved cksum().
  * expanded test cases.
- Update patch:
  * bittwist-makefile.diff
- Update URL
* Fri May 26 2017 jengelh@inai.de
- Trim filler wording from description.
* Sat Jan  2 2016 mardnh@gmx.de
- initial package, version 2.0
